import Kitura

let router = Router()

class DemoMiddleware: RouterMiddleware {
    func handle(request: RouterRequest,
                response: RouterResponse,
                next: @escaping () -> Void) throws {
        
        print(request.headers)
        print(request.body)
        print(request.cookies)
        
        guard let authHeader = request.headers["Authorization"] else {
            response.status(HTTPStatusCode(rawValue: 401)!)
            response.send(json: ["reason": "No auth header set."])
            return
        }
        
        // Add some data to the request which can be read in subsequent middlewares and handlers.
        request.userInfo["authorized"] = authHeader == "this is secret"
        next()
    }
}

//router.all(middleware: DemoMiddleware())

router.get("/info") { request, response, next in
    response.send("Hey, is this thing on?")
}

struct User: Codable {
    let name: String
    let isAdmin: Bool
}

router.get("/user") { request, response, next in
    guard let userName = request.queryParameters["name"] else {
        response.status(HTTPStatusCode(rawValue: 400)!)
        response.send(json: ["reason": "No name set."])
        return
    }
    
    let user = User(name: userName, isAdmin: Bool.random())
    response.send(user)
}
    
import SwiftKuery
import SwiftKueryORM
import SwiftKueryPostgreSQL

struct UserModel: Model {
    let name: String
    let age: Int
    let mail: String
    
    static func find(with name: String, completion: @escaping ([UserModel]?, RequestError?) -> Void) {
        do {
            let table = try UserModel.getTable()
            // THIS IS NOT SAFE AGAINST SQL INJECTION
            // Please read the documentation carefully before implementing something like this.
            // The documentation gives very good advice on how to implement this securely.
            let query = Select(from: table).where("name = '\(name)'")
            
            UserModel.executeQuery(query: query) { (results, error) in
                if let error = error {
                    return completion(nil, error)
                }
                
                guard let results = results, results.count > 0 else {
                    return completion(nil, RequestError(rawValue: 404))
                }
                
                return completion(results, nil)
            }
        } catch {
            print(error)
            return completion(nil, RequestError(rawValue: 500))
        }
    }
}

let pool = PostgreSQLConnection.createPool(host: "localhost.com",
                                           port: 5432,
                                           options: [ConnectionOptions.userName("schlabbi"),
                                                     ConnectionOptions.databaseName("kiturademo")],
                                           poolOptions: ConnectionPoolOptions(initialCapacity: 10, maxCapacity: 50))
Database.default = Database(pool)

do {
    try UserModel.createTableSync()
} catch {
    print(error)
}

router.post("/usermodel") { (user: UserModel, completion: @escaping (UserModel?, RequestError?) -> Void) in
    user.save(completion)
}

router.get("/usermodel") { (name: String, completion: @escaping([UserModel]?, RequestError?) -> Void) in
    UserModel.find(with: name, completion: completion)
}

Kitura.addHTTPServer(onPort: 8080, with: router)

Kitura.run()
