//
//  UserModel.swift
//  App
//
//  Created by Jonas Schlabertz on 18.01.20.
//

import Vapor
import Fluent
import FluentPostgreSQL

final class UserModel: PostgreSQLModel {
    var id: Int?
    
    var name: String
    var mail: String
    // Now additionally store the user's age
    var age: Int
}

extension UserModel: Content { }
extension UserModel: Parameter { }
extension UserModel: Migration { }

// Database migration to add the 'age' field to the user database representation.
// The user's age is set to a default value of -1.
struct UserModelMigration: Migration {
    
    typealias Database = PostgreSQLDatabase
    
    static func prepare(on conn: PostgreSQLConnection) -> EventLoopFuture<Void> {
        return PostgreSQLDatabase.update(UserModel.self, on: conn) { (updater) in
            let constraint = PostgreSQLColumnConstraint.default(.literal(PostgreSQLLiteral(integerLiteral: -1)))
            updater.field(for: \.age, type: .int, constraint)
        }
    }
    
    static func revert(on conn: PostgreSQLConnection) -> EventLoopFuture<Void> {
        return PostgreSQLDatabase.update(UserModel.self, on: conn) { (updater) in
            // We don't need this... I hope
        }
    }
}

