import FluentSQLite
import Vapor
import FluentPostgreSQL

/// Called before your application initializes.
public func configure(_ config: inout Config, _ env: inout Environment, _ services: inout Services) throws {
    // Here you should add your local database configuration.
    let postgresConfig = PostgreSQLDatabaseConfig(hostname: "localhost",
                                                  port: 5432,
                                                  username: "schlabbi",
                                                  database: "vapordemo",
                                                  password: nil)
    
    services.register(postgresConfig)
    
    let postgres = PostgreSQLDatabase(config: postgresConfig)
    
    services.register(postgres)
    
    try services.register(FluentSQLiteProvider())

    // Register routes to the router
    let router = EngineRouter.default()
    
    try routes(router)
    services.register(router, as: Router.self)
    services.register { container in
        return RequestStorageService()
    }

    // Register middleware
    var middlewares = MiddlewareConfig() // Create _empty_ middleware config
    // middlewares.use(FileMiddleware.self) // Serves files from `Public/` directory
    middlewares.use(ErrorMiddleware.self) // Catches errors and converts to HTTP response
    middlewares.use(DemoMiddleware())
    services.register(middlewares)

    // Configure a SQLite database
    let sqlite = try SQLiteDatabase(storage: .memory)

    // Register the configured SQLite database to the database config.
    var databases = DatabasesConfig()
    databases.add(database: sqlite, as: .sqlite)
    databases.add(database: postgres, as: .psql)
    services.register(databases)

    // Configure migrations
    var migrations = MigrationConfig()
    migrations.add(model: Todo.self, database: .sqlite)
    migrations.add(model: UserModel.self, database: .psql)
    
    // In the demo we added a new field to the UserModel. This field was intended to represent the user's age.
    // However, to make this work in conjuntion with the database, we needed to migrate the existing database schema and table entries
    // to also include this new property.
    //
    // The default UserModel migration (registered just in the line above this comment) will add all fields contained in the UserModel struct
    // to the database schema. Thus if the UserModel already contains the 'age' field at the first start, this migration will fail as the field is
    // already present in the database. Therefore, either remove the 'age' field from the UserModel before the first start or do not run this migration.
    //migrations.add(migration: UserModelMigration.self, database: .psql)
    
    services.register(migrations)
}
