import Vapor

/// Register your application's routes here.
public func routes(_ router: Router) throws {
    // Basic "It works" example
    router.get { req -> String in
        let storage = try req.privateContainer.make(RequestStorageService.self)
        print(storage.storage)
        return "It works!"
    }
    
    // Basic "Hello, world!" example
    router.get("hello") { req -> String in
        let storage = try req.privateContainer.make(RequestStorageService.self)
        print(storage.storage)
        return "Hello, world!"
    }

    // Example of configuring a controller
    let todoController = TodoController()
    router.get("todos", use: todoController.index)
    router.post("todos", use: todoController.create)
    router.delete("todos", Todo.parameter, use: todoController.delete)
    
    router.get("/user") { request -> Future<[UserModel]> in
        // Just return all users which are saved in the database.
        return UserModel.query(on: request).all()
    }
    
    router.post("/user") { request -> Future<UserModel> in
        // Decode the user from the request body and save it in the database.
        return try request.content.decode(UserModel.self).flatMap { user in
            return user.save(on: request)
        }
    }
}
